==> scummvm_2.8.0+dfsg.orig.tar.xz: scummvm-2.8.0/engines/director/lingo/xlibs/consumer.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DIRECTOR_LINGO_XLIBS_CONSUMER_H
#define DIRECTOR_LINGO_XLIBS_CONSUMER_H

namespace Director {

class ConsumerXObject : public Object<ConsumerXObject> {
public:
	ConsumerXObject(ObjectType objType);
};

namespace ConsumerXObj {

extern const char *xlibName;
extern const char *fileNames[];

void open(int type);
void close(int type);

void m_new(int nargs);
void m_dispose(int nargs);
void m_name(int nargs);
void m_settingsDlg(int nargs);
void m_popHotword(int nargs);
void m_explore(int nargs);
void m_prefSetValue(int nargs);
void m_prefGetValue(int nargs);
void m_contentLock(int nargs);
void m_getRecord(int nargs);
void m_getWinIniEntry(int nargs);
void m_aboutDlg(int nargs);
void m_registerDlg(int nargs);
void m_lockedDlg(int nargs);
void m_checkCD(int nargs);
void m_hackMenu(int nargs);

} // End of namespace ConsumerXObj

} // End of namespace Director

#endif

==> scummvm_2.9.1+dfsg.orig.tar.xz: scummvm-2.9.1/engines/director/lingo/xlibs/consumer.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DIRECTOR_LINGO_XLIBS_CONSUMER_H
#define DIRECTOR_LINGO_XLIBS_CONSUMER_H

namespace Director {

class ConsumerXObject : public Object<ConsumerXObject> {
public:
	ConsumerXObject(ObjectType objType);
};

namespace ConsumerXObj {

extern const char *const xlibName;
extern const XlibFileDesc fileNames[];

void open(ObjectType type, const Common::Path &path);
void close(ObjectType type);

void m_new(int nargs);
void m_dispose(int nargs);
void m_name(int nargs);
void m_settingsDlg(int nargs);
void m_popHotword(int nargs);
void m_explore(int nargs);
void m_prefSetValue(int nargs);
void m_prefGetValue(int nargs);
void m_contentLock(int nargs);
void m_getRecord(int nargs);
void m_getWinIniEntry(int nargs);
void m_aboutDlg(int nargs);
void m_registerDlg(int nargs);
void m_lockedDlg(int nargs);
void m_checkCD(int nargs);
void m_hackMenu(int nargs);

} // End of namespace ConsumerXObj

} // End of namespace Director

#endif
